@@ -122,46 +122,46 @@ var NAVTREEINDEX2 =
 "classlibcamera_1_1Size.html#a0063ea1917eeaa0b34a4cf21507dea25":[6,0,0,22,24],
 "classlibcamera_1_1Size.html#a053534ab91440607edfefa5b259236a6":[5,0,0,24,19],
 "classlibcamera_1_1Size.html#a053534ab91440607edfefa5b259236a6":[6,0,0,22,19],
-"classlibcamera_1_1Size.html#a13017580429b6c5dd4243c3d3c22f361":[5,0,0,24,3],
-"classlibcamera_1_1Size.html#a13017580429b6c5dd4243c3d3c22f361":[6,0,0,22,3],
+"classlibcamera_1_1Size.html#a2094d73784a8aece896c364cc2bda5ca":[5,0,0,24,6],
+"classlibcamera_1_1Size.html#a2094d73784a8aece896c364cc2bda5ca":[6,0,0,22,6],
 "classlibcamera_1_1Size.html#a24a4bd7966c18df4581e2822833f364f":[5,0,0,24,0],
 "classlibcamera_1_1Size.html#a24a4bd7966c18df4581e2822833f364f":[6,0,0,22,0],
 "classlibcamera_1_1Size.html#a287a8238b720af55d5a73efeaae70b52":[5,0,0,24,22],
 "classlibcamera_1_1Size.html#a287a8238b720af55d5a73efeaae70b52":[6,0,0,22,22],
 "classlibcamera_1_1Size.html#a29b267bc4fdc51c9b50a5cc7b98ae4ba":[5,0,0,24,8],
 "classlibcamera_1_1Size.html#a29b267bc4fdc51c9b50a5cc7b98ae4ba":[6,0,0,22,8],
-"classlibcamera_1_1Size.html#a29e9192f797bdfed7e7cc060ef0e0df5":[5,0,0,24,21],
-"classlibcamera_1_1Size.html#a29e9192f797bdfed7e7cc060ef0e0df5":[6,0,0,22,21],
 "classlibcamera_1_1Size.html#a306de151d0e5134d8a7c45198293ca1c":[5,0,0,24,18],
 "classlibcamera_1_1Size.html#a306de151d0e5134d8a7c45198293ca1c":[6,0,0,22,18],
 "classlibcamera_1_1Size.html#a31490a7131f1c9b4f3befbb107724c66":[5,0,0,24,1],
 "classlibcamera_1_1Size.html#a31490a7131f1c9b4f3befbb107724c66":[6,0,0,22,1],
 "classlibcamera_1_1Size.html#a4347a68cb904284f2b062e79611c6171":[5,0,0,24,2],
 "classlibcamera_1_1Size.html#a4347a68cb904284f2b062e79611c6171":[6,0,0,22,2],
-"classlibcamera_1_1Size.html#a4e876cb018a4c84614e8e9eafc9868b9":[5,0,0,24,14],
-"classlibcamera_1_1Size.html#a4e876cb018a4c84614e8e9eafc9868b9":[6,0,0,22,14],
-"classlibcamera_1_1Size.html#a568e82f3af45963cf1d0d85a6499f9e0":[5,0,0,24,4],
-"classlibcamera_1_1Size.html#a568e82f3af45963cf1d0d85a6499f9e0":[6,0,0,22,4],
+"classlibcamera_1_1Size.html#a4472b3632a36be3b467af3294445a929":[5,0,0,24,21],
+"classlibcamera_1_1Size.html#a4472b3632a36be3b467af3294445a929":[6,0,0,22,21],
 "classlibcamera_1_1Size.html#a6149c0f2566078baf4ee624b9d5530e0":[5,0,0,24,5],
 "classlibcamera_1_1Size.html#a6149c0f2566078baf4ee624b9d5530e0":[6,0,0,22,5],
 "classlibcamera_1_1Size.html#a660e034e48e25ae5f28ba57e7e36e02a":[5,0,0,24,20],
 "classlibcamera_1_1Size.html#a660e034e48e25ae5f28ba57e7e36e02a":[6,0,0,22,20],
 "classlibcamera_1_1Size.html#a6f886d9bf022d6ebcae11f01a4973749":[5,0,0,24,23],
 "classlibcamera_1_1Size.html#a6f886d9bf022d6ebcae11f01a4973749":[6,0,0,22,23],
+"classlibcamera_1_1Size.html#a726a1ddda26e63b7e5e9a05c7a2dd97e":[5,0,0,24,3],
+"classlibcamera_1_1Size.html#a726a1ddda26e63b7e5e9a05c7a2dd97e":[6,0,0,22,3],
 "classlibcamera_1_1Size.html#a81356ac0a1b2229fa1f4874ac7848aed":[5,0,0,24,9],
 "classlibcamera_1_1Size.html#a81356ac0a1b2229fa1f4874ac7848aed":[6,0,0,22,9],
-"classlibcamera_1_1Size.html#a88e7e0a313eebadacfb308dad8ae3a84":[5,0,0,24,10],
-"classlibcamera_1_1Size.html#a88e7e0a313eebadacfb308dad8ae3a84":[6,0,0,22,10],
 "classlibcamera_1_1Size.html#a943251f772ca06110f811e63cf241b73":[5,0,0,24,15],
 "classlibcamera_1_1Size.html#a943251f772ca06110f811e63cf241b73":[6,0,0,22,15],
+"classlibcamera_1_1Size.html#aa785b0eb305fa34fd79c6568a73c7b7b":[5,0,0,24,4],
+"classlibcamera_1_1Size.html#aa785b0eb305fa34fd79c6568a73c7b7b":[6,0,0,22,4],
 "classlibcamera_1_1Size.html#ab44f288148efb162ba9d2d54cf844242":[5,0,0,24,7],
 "classlibcamera_1_1Size.html#ab44f288148efb162ba9d2d54cf844242":[6,0,0,22,7],
 "classlibcamera_1_1Size.html#ac171509875241ae63e2a56dd3c68a125":[5,0,0,24,11],
 "classlibcamera_1_1Size.html#ac171509875241ae63e2a56dd3c68a125":[6,0,0,22,11],
+"classlibcamera_1_1Size.html#ad1cff65807a9b5506eb8a4f113717b95":[5,0,0,24,10],
+"classlibcamera_1_1Size.html#ad1cff65807a9b5506eb8a4f113717b95":[6,0,0,22,10],
 "classlibcamera_1_1Size.html#ad24b1c42470671086839f18e04f5d3c3":[5,0,0,24,16],
 "classlibcamera_1_1Size.html#ad24b1c42470671086839f18e04f5d3c3":[6,0,0,22,16],
-"classlibcamera_1_1Size.html#adf1ad11e34e8d3d64577c6c8b2d6932b":[5,0,0,24,6],
-"classlibcamera_1_1Size.html#adf1ad11e34e8d3d64577c6c8b2d6932b":[6,0,0,22,6],
+"classlibcamera_1_1Size.html#ada54f76dd0ab7466847d422e30150353":[5,0,0,24,14],
+"classlibcamera_1_1Size.html#ada54f76dd0ab7466847d422e30150353":[6,0,0,22,14],
 "classlibcamera_1_1Size.html#ae692c5956339c551f4046b542f01dcee":[5,0,0,24,12],
 "classlibcamera_1_1Size.html#ae692c5956339c551f4046b542f01dcee":[6,0,0,22,12],
 "classlibcamera_1_1Size.html#af0c3b69926ce4dfcd29658652fc0188d":[5,0,0,24,13],
@@ -210,6 +210,8 @@ var NAVTREEINDEX2 =
 "classlibcamera_1_1StreamFormats.html#ab956a73dcc86314d903227ad736a29a4":[6,0,0,26,1],
 "classlibcamera_1_1UniqueFD.html":[5,0,0,29],
 "classlibcamera_1_1UniqueFD.html":[6,0,0,27],
+"classlibcamera_1_1UniqueFD.html#a037733b3d6ffcbe457462096b9a6dda3":[5,0,0,29,7],
+"classlibcamera_1_1UniqueFD.html#a037733b3d6ffcbe457462096b9a6dda3":[6,0,0,27,7],
 "classlibcamera_1_1UniqueFD.html#a3e2ecb3a2538d7af083203b14d494643":[5,0,0,29,6],
 "classlibcamera_1_1UniqueFD.html#a3e2ecb3a2538d7af083203b14d494643":[6,0,0,27,6],
 "classlibcamera_1_1UniqueFD.html#a48adae4c31897235fe0c5db1bd7412cf":[5,0,0,29,3],
@@ -226,13 +228,10 @@ var NAVTREEINDEX2 =
 "classlibcamera_1_1UniqueFD.html#a9e3fd07cc88d87a22c9918f2a11e3640":[6,0,0,27,5],
 "classlibcamera_1_1UniqueFD.html#ad3d440cf697135108dc8bcd75533f382":[5,0,0,29,4],
 "classlibcamera_1_1UniqueFD.html#ad3d440cf697135108dc8bcd75533f382":[6,0,0,27,4],
-"classlibcamera_1_1UniqueFD.html#af10ee77caee9ab1f5184706ba1864922":[5,0,0,29,7],
-"classlibcamera_1_1UniqueFD.html#af10ee77caee9ab1f5184706ba1864922":[6,0,0,27,7],
 "classlibcamera_1_1UniqueFD.html#af22d8122d42de7927dbedbdf730d04d0":[5,0,0,29,8],
 "classlibcamera_1_1UniqueFD.html#af22d8122d42de7927dbedbdf730d04d0":[6,0,0,27,8],
 "color__space_8h.html":[7,0,1,0,3],
 "color__space_8h_source.html":[7,0,1,0,3],
-"compiler_8h_source.html":[7,0,1,0,0,1],
 "context.html":[3],
 "control__ids_8h.html":[7,0,0,0,0,0],
 "control__ids_8h_source.html":[7,0,0,0,0,0],
@@ -247,7 +246,8 @@ var NAVTREEINDEX2 =
 "fence_8h.html":[7,0,1,0,5],
 "fence_8h_source.html":[7,0,1,0,5],
 "files.html":[7,0],
-"flags_8h.html":[7,0,1,0,0,2],
-"flags_8h.html#af343143bcb24209ae99e7bf7e28936a1":[7,0,1,0,0,2,1],
-"flags_8h_source.html":[7,0,1,0,0,2]
+"flags_8h.html":[7,0,1,0,0,1],
+"flags_8h.html#af343143bcb24209ae99e7bf7e28936a1":[7,0,1,0,0,1,1],
+"flags_8h_source.html":[7,0,1,0,0,1],
+"formats_8h_source.html":[7,0,0,0,0,1]
 };
