@@ -7,7 +7,7 @@ var indexSectionsWithContent =
   4: "abcdefghimnopqrstuv~",
   5: "abcdefghklmnoprstuvwxy",
   6: "bcdimt",
-  7: "acdfhlmnoprsty",
+  7: "acdefhlmnoprsty",
   8: "abcdefghiklmnorstv",
   9: "l",
   10: "aclmrst"
