@@ -7,8 +7,10 @@ var NAVTREEINDEX0 =
 "agc__mean__luminance_8h.html":[8,0,2,0,1,0],
 "agc__mean__luminance_8h_source.html":[8,0,2,0,1,0],
 "annotated.html":[7,0],
-"awb_8h.html":[8,0,2,0,0,0,3],
-"awb_8h_source.html":[8,0,2,0,0,0,3],
+"awb__bayes_8h.html":[8,0,2,0,1,3],
+"awb__bayes_8h_source.html":[8,0,2,0,1,3],
+"awb__grey_8h.html":[8,0,2,0,1,4],
+"awb__grey_8h_source.html":[8,0,2,0,1,4],
 "backtrace_8h.html":[8,0,1,0,0,0],
 "backtrace_8h_source.html":[8,0,1,0,0,0],
 "bayer__format_8h.html":[8,0,1,0,1,2],
@@ -35,9 +37,9 @@ var NAVTREEINDEX0 =
 "camera__sensor_8h.html":[8,0,1,0,1,8],
 "camera__sensor_8h.html#a4eb72a0c095a1f9293905d047f75ef18":[8,0,1,0,1,8,3],
 "camera__sensor_8h_source.html":[8,0,1,0,1,8],
-"camera__sensor__helper_8h.html":[8,0,2,0,1,2],
-"camera__sensor__helper_8h.html#a1b196d050477cdb5d27441679ff53a1b":[8,0,2,0,1,2,5],
-"camera__sensor__helper_8h_source.html":[8,0,2,0,1,2],
+"camera__sensor__helper_8h.html":[8,0,2,0,1,5],
+"camera__sensor__helper_8h.html#a1b196d050477cdb5d27441679ff53a1b":[8,0,2,0,1,5,5],
+"camera__sensor__helper_8h_source.html":[8,0,2,0,1,5],
 "camera__sensor__properties_8h.html":[8,0,1,0,1,9],
 "camera__sensor__properties_8h_source.html":[8,0,1,0,1,9],
 "class_8h.html":[8,0,1,0,0,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX0 =
 "classlibcamera_1_1CameraLens.html#ad998675c5a46796afe4a2c42a5458ec6":[7,0,0,8,1],
 "classlibcamera_1_1CameraLens.html#ae47356daba26c29aabdf3fc2d4190023":[6,0,0,9,2],
 "classlibcamera_1_1CameraLens.html#ae47356daba26c29aabdf3fc2d4190023":[7,0,0,8,2],
-"classlibcamera_1_1CameraManager.html":[6,0,0,10],
-"classlibcamera_1_1CameraManager.html":[7,0,0,9],
-"classlibcamera_1_1CameraManager.html#a3b20427687e9920b256625838bea8f9a":[6,0,0,10,1]
+"classlibcamera_1_1CameraManager.html":[6,0,0,10]
 };
