@@ -1,12 +1,14 @@
 var NAVTREEINDEX1 =
 {
+"classlibcamera_1_1CameraManager.html":[7,0,0,9],
+"classlibcamera_1_1CameraManager.html#a004d822ffc9ad72137711ce20aebb7cc":[6,0,0,10,2],
+"classlibcamera_1_1CameraManager.html#a004d822ffc9ad72137711ce20aebb7cc":[7,0,0,9,2],
+"classlibcamera_1_1CameraManager.html#a3b20427687e9920b256625838bea8f9a":[6,0,0,10,1],
 "classlibcamera_1_1CameraManager.html#a3b20427687e9920b256625838bea8f9a":[7,0,0,9,1],
 "classlibcamera_1_1CameraManager.html#a49e322880a2a26013bb0076788b298c5":[6,0,0,10,3],
 "classlibcamera_1_1CameraManager.html#a49e322880a2a26013bb0076788b298c5":[7,0,0,9,3],
 "classlibcamera_1_1CameraManager.html#abcf2a1b9ca720891e6bd83b3c542bb61":[6,0,0,10,4],
 "classlibcamera_1_1CameraManager.html#abcf2a1b9ca720891e6bd83b3c542bb61":[7,0,0,9,4],
-"classlibcamera_1_1CameraManager.html#abd8bfe0d85cedf2ec5c4549d05de7f09":[6,0,0,10,2],
-"classlibcamera_1_1CameraManager.html#abd8bfe0d85cedf2ec5c4549d05de7f09":[7,0,0,9,2],
 "classlibcamera_1_1CameraManager.html#ada5dc73ab3d0acffeb9ed4b742480a2e":[6,0,0,10,5],
 "classlibcamera_1_1CameraManager.html#ada5dc73ab3d0acffeb9ed4b742480a2e":[7,0,0,9,5],
 "classlibcamera_1_1CameraManager.html#adea06b949914f533de33a8ae43d60837":[6,0,0,10,6],
@@ -15,52 +17,60 @@ var NAVTREEINDEX1 =
 "classlibcamera_1_1CameraManager.html#ae8647ec4748314069fbc5e0ee3c3e74b":[7,0,0,9,0],
 "classlibcamera_1_1CameraSensor.html":[6,0,0,11],
 "classlibcamera_1_1CameraSensor.html":[7,0,0,10],
-"classlibcamera_1_1CameraSensor.html#a05bce811fc583fe704e1bafe10bbe768":[6,0,0,11,17],
-"classlibcamera_1_1CameraSensor.html#a05bce811fc583fe704e1bafe10bbe768":[7,0,0,10,17],
+"classlibcamera_1_1CameraSensor.html#a05bce811fc583fe704e1bafe10bbe768":[6,0,0,11,20],
+"classlibcamera_1_1CameraSensor.html#a05bce811fc583fe704e1bafe10bbe768":[7,0,0,10,20],
+"classlibcamera_1_1CameraSensor.html#a0d1c0bf3a11a16227d5428cb49e182d4":[6,0,0,11,13],
+"classlibcamera_1_1CameraSensor.html#a0d1c0bf3a11a16227d5428cb49e182d4":[7,0,0,10,13],
 "classlibcamera_1_1CameraSensor.html#a0fbd9f6155ef26aac8b0b18f0b40da51":[6,0,0,11,3],
 "classlibcamera_1_1CameraSensor.html#a0fbd9f6155ef26aac8b0b18f0b40da51":[7,0,0,10,3],
-"classlibcamera_1_1CameraSensor.html#a0fea5ab1377957bc4aaa1bbe794898b3":[6,0,0,11,13],
-"classlibcamera_1_1CameraSensor.html#a0fea5ab1377957bc4aaa1bbe794898b3":[7,0,0,10,13],
-"classlibcamera_1_1CameraSensor.html#a16912cf9129bc2de4431328ef8207f47":[6,0,0,11,8],
-"classlibcamera_1_1CameraSensor.html#a16912cf9129bc2de4431328ef8207f47":[7,0,0,10,8],
-"classlibcamera_1_1CameraSensor.html#a190da5e09fac3d44238cfeae1933e7d9":[6,0,0,11,12],
-"classlibcamera_1_1CameraSensor.html#a190da5e09fac3d44238cfeae1933e7d9":[7,0,0,10,12],
+"classlibcamera_1_1CameraSensor.html#a0fea5ab1377957bc4aaa1bbe794898b3":[6,0,0,11,16],
+"classlibcamera_1_1CameraSensor.html#a0fea5ab1377957bc4aaa1bbe794898b3":[7,0,0,10,16],
+"classlibcamera_1_1CameraSensor.html#a16912cf9129bc2de4431328ef8207f47":[6,0,0,11,10],
+"classlibcamera_1_1CameraSensor.html#a16912cf9129bc2de4431328ef8207f47":[7,0,0,10,10],
+"classlibcamera_1_1CameraSensor.html#a190da5e09fac3d44238cfeae1933e7d9":[6,0,0,11,15],
+"classlibcamera_1_1CameraSensor.html#a190da5e09fac3d44238cfeae1933e7d9":[7,0,0,10,15],
 "classlibcamera_1_1CameraSensor.html#a356c31644de465032fdbe7473515ca51":[6,0,0,11,2],
 "classlibcamera_1_1CameraSensor.html#a356c31644de465032fdbe7473515ca51":[7,0,0,10,2],
-"classlibcamera_1_1CameraSensor.html#a4081e45b38a00007fb932c629dca9fea":[6,0,0,11,10],
-"classlibcamera_1_1CameraSensor.html#a4081e45b38a00007fb932c629dca9fea":[7,0,0,10,10],
+"classlibcamera_1_1CameraSensor.html#a4081e45b38a00007fb932c629dca9fea":[6,0,0,11,12],
+"classlibcamera_1_1CameraSensor.html#a4081e45b38a00007fb932c629dca9fea":[7,0,0,10,12],
 "classlibcamera_1_1CameraSensor.html#a42aac0ff1b254b332982bd74cc7e1bae":[6,0,0,11,4],
 "classlibcamera_1_1CameraSensor.html#a42aac0ff1b254b332982bd74cc7e1bae":[7,0,0,10,4],
-"classlibcamera_1_1CameraSensor.html#a621204bd4e47bd7f2ed338b608b0a0cc":[6,0,0,11,22],
-"classlibcamera_1_1CameraSensor.html#a621204bd4e47bd7f2ed338b608b0a0cc":[7,0,0,10,22],
+"classlibcamera_1_1CameraSensor.html#a621204bd4e47bd7f2ed338b608b0a0cc":[6,0,0,11,26],
+"classlibcamera_1_1CameraSensor.html#a621204bd4e47bd7f2ed338b608b0a0cc":[7,0,0,10,26],
 "classlibcamera_1_1CameraSensor.html#a62541b847d81210c72493f9e49fc9b1d":[6,0,0,11,0],
 "classlibcamera_1_1CameraSensor.html#a62541b847d81210c72493f9e49fc9b1d":[7,0,0,10,0],
-"classlibcamera_1_1CameraSensor.html#a6c7717aec35f905563b7452560ca82ef":[6,0,0,11,14],
-"classlibcamera_1_1CameraSensor.html#a6c7717aec35f905563b7452560ca82ef":[7,0,0,10,14],
-"classlibcamera_1_1CameraSensor.html#a6f91aa3ff17b8904e2aac5d3cea3ea49":[6,0,0,11,18],
-"classlibcamera_1_1CameraSensor.html#a6f91aa3ff17b8904e2aac5d3cea3ea49":[7,0,0,10,18],
-"classlibcamera_1_1CameraSensor.html#a7d062b4ba6c0369079af21fea618e00c":[6,0,0,11,21],
-"classlibcamera_1_1CameraSensor.html#a7d062b4ba6c0369079af21fea618e00c":[7,0,0,10,21],
-"classlibcamera_1_1CameraSensor.html#a7fc60f97b4bee551057fb93c81f4ce6f":[6,0,0,11,15],
-"classlibcamera_1_1CameraSensor.html#a7fc60f97b4bee551057fb93c81f4ce6f":[7,0,0,10,15],
-"classlibcamera_1_1CameraSensor.html#a8f2f09afd51003f186bbf8afd412a25a":[6,0,0,11,11],
-"classlibcamera_1_1CameraSensor.html#a8f2f09afd51003f186bbf8afd412a25a":[7,0,0,10,11],
-"classlibcamera_1_1CameraSensor.html#a99756eb3d9adccc250c9add664c6bfc7":[6,0,0,11,19],
-"classlibcamera_1_1CameraSensor.html#a99756eb3d9adccc250c9add664c6bfc7":[7,0,0,10,19],
+"classlibcamera_1_1CameraSensor.html#a6c7717aec35f905563b7452560ca82ef":[6,0,0,11,17],
+"classlibcamera_1_1CameraSensor.html#a6c7717aec35f905563b7452560ca82ef":[7,0,0,10,17],
+"classlibcamera_1_1CameraSensor.html#a6f91aa3ff17b8904e2aac5d3cea3ea49":[6,0,0,11,22],
+"classlibcamera_1_1CameraSensor.html#a6f91aa3ff17b8904e2aac5d3cea3ea49":[7,0,0,10,22],
+"classlibcamera_1_1CameraSensor.html#a7d062b4ba6c0369079af21fea618e00c":[6,0,0,11,25],
+"classlibcamera_1_1CameraSensor.html#a7d062b4ba6c0369079af21fea618e00c":[7,0,0,10,25],
+"classlibcamera_1_1CameraSensor.html#a7fc60f97b4bee551057fb93c81f4ce6f":[6,0,0,11,18],
+"classlibcamera_1_1CameraSensor.html#a7fc60f97b4bee551057fb93c81f4ce6f":[7,0,0,10,18],
+"classlibcamera_1_1CameraSensor.html#a8f2f09afd51003f186bbf8afd412a25a":[6,0,0,11,14],
+"classlibcamera_1_1CameraSensor.html#a8f2f09afd51003f186bbf8afd412a25a":[7,0,0,10,14],
+"classlibcamera_1_1CameraSensor.html#a94570862c6d29319c6abffa3685566ba":[6,0,0,11,7],
+"classlibcamera_1_1CameraSensor.html#a94570862c6d29319c6abffa3685566ba":[7,0,0,10,7],
+"classlibcamera_1_1CameraSensor.html#a99756eb3d9adccc250c9add664c6bfc7":[6,0,0,11,23],
+"classlibcamera_1_1CameraSensor.html#a99756eb3d9adccc250c9add664c6bfc7":[7,0,0,10,23],
 "classlibcamera_1_1CameraSensor.html#a9d7ce4818dc94c27870cb8eb83e12dd9":[6,0,0,11,1],
 "classlibcamera_1_1CameraSensor.html#a9d7ce4818dc94c27870cb8eb83e12dd9":[7,0,0,10,1],
-"classlibcamera_1_1CameraSensor.html#aaeda651ef0ab06c1d5942d8a5b8383f1":[6,0,0,11,7],
-"classlibcamera_1_1CameraSensor.html#aaeda651ef0ab06c1d5942d8a5b8383f1":[7,0,0,10,7],
-"classlibcamera_1_1CameraSensor.html#ab7c34a5f5250c023d2cb88559ba10d31":[6,0,0,11,20],
-"classlibcamera_1_1CameraSensor.html#ab7c34a5f5250c023d2cb88559ba10d31":[7,0,0,10,20],
-"classlibcamera_1_1CameraSensor.html#ae58f6b44a61459a5d596ba5dd3bf9c7b":[6,0,0,11,6],
-"classlibcamera_1_1CameraSensor.html#ae58f6b44a61459a5d596ba5dd3bf9c7b":[7,0,0,10,6],
-"classlibcamera_1_1CameraSensor.html#ae9492bd7ae21cc7867835bf971ab6bf5":[6,0,0,11,9],
-"classlibcamera_1_1CameraSensor.html#ae9492bd7ae21cc7867835bf971ab6bf5":[7,0,0,10,9],
-"classlibcamera_1_1CameraSensor.html#af8d330aefbc31e08ca1ecee5e4184650":[6,0,0,11,16],
-"classlibcamera_1_1CameraSensor.html#af8d330aefbc31e08ca1ecee5e4184650":[7,0,0,10,16],
+"classlibcamera_1_1CameraSensor.html#aaeda651ef0ab06c1d5942d8a5b8383f1":[6,0,0,11,9],
+"classlibcamera_1_1CameraSensor.html#aaeda651ef0ab06c1d5942d8a5b8383f1":[7,0,0,10,9],
+"classlibcamera_1_1CameraSensor.html#ab225d478fe6333c82b2663d1d385c1ab":[6,0,0,11,21],
+"classlibcamera_1_1CameraSensor.html#ab225d478fe6333c82b2663d1d385c1ab":[7,0,0,10,21],
+"classlibcamera_1_1CameraSensor.html#ab7c34a5f5250c023d2cb88559ba10d31":[6,0,0,11,24],
+"classlibcamera_1_1CameraSensor.html#ab7c34a5f5250c023d2cb88559ba10d31":[7,0,0,10,24],
+"classlibcamera_1_1CameraSensor.html#ae58f6b44a61459a5d596ba5dd3bf9c7b":[6,0,0,11,8],
+"classlibcamera_1_1CameraSensor.html#ae58f6b44a61459a5d596ba5dd3bf9c7b":[7,0,0,10,8],
+"classlibcamera_1_1CameraSensor.html#ae9492bd7ae21cc7867835bf971ab6bf5":[6,0,0,11,11],
+"classlibcamera_1_1CameraSensor.html#ae9492bd7ae21cc7867835bf971ab6bf5":[7,0,0,10,11],
+"classlibcamera_1_1CameraSensor.html#af8d330aefbc31e08ca1ecee5e4184650":[6,0,0,11,19],
+"classlibcamera_1_1CameraSensor.html#af8d330aefbc31e08ca1ecee5e4184650":[7,0,0,10,19],
 "classlibcamera_1_1CameraSensor.html#afb6a69c1acb3bc086919d539923967c2":[6,0,0,11,5],
 "classlibcamera_1_1CameraSensor.html#afb6a69c1acb3bc086919d539923967c2":[7,0,0,10,5],
+"classlibcamera_1_1CameraSensor.html#afeefe86f854ddbcbec8bea40a1798150":[6,0,0,11,6],
+"classlibcamera_1_1CameraSensor.html#afeefe86f854ddbcbec8bea40a1798150":[7,0,0,10,6],
 "classlibcamera_1_1CameraSensorFactory.html":[6,0,0,12],
 "classlibcamera_1_1CameraSensorFactory.html":[7,0,0,11],
 "classlibcamera_1_1CameraSensorFactory.html#a46dca79c0167ef94af1b4989076254ec":[6,0,0,12,0],
@@ -239,15 +249,5 @@ var NAVTREEINDEX1 =
 "classlibcamera_1_1ControlList.html#a0ee4ebfefe21503301cd9fc33d715453":[7,0,0,20,1],
 "classlibcamera_1_1ControlList.html#a1767710105b2d146dd22e2bebc841419":[6,0,0,21,20],
 "classlibcamera_1_1ControlList.html#a1767710105b2d146dd22e2bebc841419":[7,0,0,20,20],
-"classlibcamera_1_1ControlList.html#a39120e9db432c3abfd95a8615e2a3981":[6,0,0,21,16],
-"classlibcamera_1_1ControlList.html#a39120e9db432c3abfd95a8615e2a3981":[7,0,0,20,16],
-"classlibcamera_1_1ControlList.html#a3e42fae5ad768a5bfb69ccc389d665a0":[6,0,0,21,11],
-"classlibcamera_1_1ControlList.html#a3e42fae5ad768a5bfb69ccc389d665a0":[7,0,0,20,11],
-"classlibcamera_1_1ControlList.html#a61c8b9a57df34e40716d3664d24df80d":[6,0,0,21,2],
-"classlibcamera_1_1ControlList.html#a61c8b9a57df34e40716d3664d24df80d":[7,0,0,20,2],
-"classlibcamera_1_1ControlList.html#a61c8b9a57df34e40716d3664d24df80da213fc6f9c23a879020bc94b79cc51d62":[6,0,0,21,2,1],
-"classlibcamera_1_1ControlList.html#a61c8b9a57df34e40716d3664d24df80da213fc6f9c23a879020bc94b79cc51d62":[7,0,0,20,2,1],
-"classlibcamera_1_1ControlList.html#a61c8b9a57df34e40716d3664d24df80da52a9854287113e3ba9a005ff73c54c7b":[6,0,0,21,2,0],
-"classlibcamera_1_1ControlList.html#a61c8b9a57df34e40716d3664d24df80da52a9854287113e3ba9a005ff73c54c7b":[7,0,0,20,2,0],
-"classlibcamera_1_1ControlList.html#a65f20b02b0dd3ecf56a7c862123de5c4":[6,0,0,21,21]
+"classlibcamera_1_1ControlList.html#a39120e9db432c3abfd95a8615e2a3981":[6,0,0,21,16]
 };
