@@ -1,22 +1,38 @@
 var NAVTREEINDEX10 =
 {
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html":[7,0,0,0,4],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a0ad9d48552c898e39fe0ca1a105aefd4":[6,0,0,1,3,2],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a0ad9d48552c898e39fe0ca1a105aefd4":[7,0,0,0,4,2],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a12ae8e0b7dc2af11b9b581355dfc207d":[6,0,0,1,3,5],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a12ae8e0b7dc2af11b9b581355dfc207d":[7,0,0,0,4,5],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a200e3a5dd006961c3e1fd8e683eac635":[6,0,0,1,3,7],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a200e3a5dd006961c3e1fd8e683eac635":[7,0,0,0,4,7],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a20a98f79040c31413d0ff9a3be0d558e":[6,0,0,1,3,6],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a20a98f79040c31413d0ff9a3be0d558e":[7,0,0,0,4,6],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a5501565234441d0740302470ff1ea599":[6,0,0,1,3,3],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a5501565234441d0740302470ff1ea599":[7,0,0,0,4,3],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a724a42217b2b153b2b055facd66a5f34":[6,0,0,1,3,4],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a724a42217b2b153b2b055facd66a5f34":[7,0,0,0,4,4],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a8c73b5e00c2d7e6603de3549663f44d1":[6,0,0,1,3,1],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#a8c73b5e00c2d7e6603de3549663f44d1":[7,0,0,0,4,1],
+"classlibcamera_1_1ipa_1_1AwbAlgorithm.html#ac9f967a7375681e18eb1c116d191519d":[6,0,0,1,3,8],
 "classlibcamera_1_1ipa_1_1AwbAlgorithm.html#ac9f967a7375681e18eb1c116d191519d":[7,0,0,0,4,8],
 "classlibcamera_1_1ipa_1_1AwbBayes.html":[6,0,0,1,4],
 "classlibcamera_1_1ipa_1_1AwbBayes.html":[7,0,0,0,5],
 "classlibcamera_1_1ipa_1_1AwbBayes.html#a0101ab013fad1e6fa77cb20571e35d4f":[6,0,0,1,4,3],
 "classlibcamera_1_1ipa_1_1AwbBayes.html#a0101ab013fad1e6fa77cb20571e35d4f":[7,0,0,0,5,3],
+"classlibcamera_1_1ipa_1_1AwbBayes.html#a01fda1757d342330d1d4853d7cabb61e":[6,0,0,1,4,1],
+"classlibcamera_1_1ipa_1_1AwbBayes.html#a01fda1757d342330d1d4853d7cabb61e":[7,0,0,0,5,1],
 "classlibcamera_1_1ipa_1_1AwbBayes.html#a2d650b8364f7636a946abbbb2c30e32e":[6,0,0,1,4,0],
 "classlibcamera_1_1ipa_1_1AwbBayes.html#a2d650b8364f7636a946abbbb2c30e32e":[7,0,0,0,5,0],
 "classlibcamera_1_1ipa_1_1AwbBayes.html#ac4a1dc63614e7982afb5aab8c71e614d":[6,0,0,1,4,2],
 "classlibcamera_1_1ipa_1_1AwbBayes.html#ac4a1dc63614e7982afb5aab8c71e614d":[7,0,0,0,5,2],
-"classlibcamera_1_1ipa_1_1AwbBayes.html#ac8b27f5f8d596e45213a14e447f1c61b":[6,0,0,1,4,1],
-"classlibcamera_1_1ipa_1_1AwbBayes.html#ac8b27f5f8d596e45213a14e447f1c61b":[7,0,0,0,5,1],
 "classlibcamera_1_1ipa_1_1AwbGrey.html":[6,0,0,1,5],
 "classlibcamera_1_1ipa_1_1AwbGrey.html":[7,0,0,0,6],
+"classlibcamera_1_1ipa_1_1AwbGrey.html#a98f3c8f8c8c7a35950aa0eb9a54fbe20":[6,0,0,1,5,1],
+"classlibcamera_1_1ipa_1_1AwbGrey.html#a98f3c8f8c8c7a35950aa0eb9a54fbe20":[7,0,0,0,6,1],
 "classlibcamera_1_1ipa_1_1AwbGrey.html#ac8dab0b901bf6efa7f36a22c5405dd04":[6,0,0,1,5,2],
 "classlibcamera_1_1ipa_1_1AwbGrey.html#ac8dab0b901bf6efa7f36a22c5405dd04":[7,0,0,0,6,2],
-"classlibcamera_1_1ipa_1_1AwbGrey.html#ad45f99a6e4159a9e66098af9c5e0f514":[6,0,0,1,5,1],
-"classlibcamera_1_1ipa_1_1AwbGrey.html#ad45f99a6e4159a9e66098af9c5e0f514":[7,0,0,0,6,1],
 "classlibcamera_1_1ipa_1_1AwbGrey.html#ae8ddc841ae5695d4a2e7b171906a23d4":[6,0,0,1,5,0],
 "classlibcamera_1_1ipa_1_1AwbGrey.html#ae8ddc841ae5695d4a2e7b171906a23d4":[7,0,0,0,6,0],
 "classlibcamera_1_1ipa_1_1CameraSensorHelper.html":[6,0,0,1,8],
@@ -233,21 +249,5 @@ var NAVTREEINDEX10 =
 "converter__v4l2__m2m_8h.html":[8,0,1,0,1,0,0],
 "converter__v4l2__m2m_8h_source.html":[8,0,1,0,1,0,0],
 "core__ipa__interface_8h.html":[8,0,0,0,0,0,0],
-"core__ipa__interface_8h_source.html":[8,0,0,0,0,0,0],
-"debayer_8h_source.html":[8,0,2,1,0,0],
-"debayer__cpu_8h_source.html":[8,0,2,1,0,1],
-"debayer__params_8h_source.html":[8,0,1,0,1,1,0],
-"debug__controls_8h.html":[8,0,1,0,1,13],
-"debug__controls_8h_source.html":[8,0,1,0,1,13],
-"delayed__controls_8h.html":[8,0,1,0,1,14],
-"delayed__controls_8h_source.html":[8,0,1,0,1,14],
-"device__enumerator_8h.html":[8,0,1,0,1,15],
-"device__enumerator_8h_source.html":[8,0,1,0,1,15],
-"dir_027bf2fab40bac5aceb28c4dcf3284f5.html":[8,0,1,0,1],
-"dir_120b71084717f0085dddebe0855f2f1c.html":[8,0,2,0,0],
-"dir_1a3f7ece52fdea1bf6e1f09d3de24e04.html":[8,0,1,0,1,1],
-"dir_1fe43409e6b351d00af13b79d21e4278.html":[8,0,1,0,2],
-"dir_3636553c781bc1baebf015442e5727b1.html":[8,0,0,0,0],
-"dir_3d9f1b59f0fa22320fa77723c4767608.html":[8,0,2,1],
-"dir_3e65f085f7436f56f469d6139426c070.html":[8,0,1,0,0]
+"core__ipa__interface_8h_source.html":[8,0,0,0,0,0,0]
 };
