@@ -1,5 +1,23 @@
 var NAVTREEINDEX13 =
 {
+"namespacelibcamera_1_1controls.html#aff89777acbe21fd9fb4ada07efc61e37":[6,0,0,0,102],
+"namespacelibcamera_1_1controls_1_1debug.html":[6,0,0,0,0],
+"namespacelibcamera_1_1controls_1_1draft.html":[6,0,0,0,1],
+"namespacelibcamera_1_1controls_1_1draft.html#a001dd6c5c5f7b0620932ae874df94b22":[6,0,0,0,1,27],
+"namespacelibcamera_1_1controls_1_1draft.html#a01d7384849d207764a59ab5204b6a55e":[6,0,0,0,1,32],
+"namespacelibcamera_1_1controls_1_1draft.html#a05a7d7e92c024aa2e64413e36524c69c":[6,0,0,0,1,12],
+"namespacelibcamera_1_1controls_1_1draft.html#a0befb55f935f77f8db1944aef6542294":[6,0,0,0,1,24],
+"namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19":[6,0,0,0,1,5],
+"namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19a00f42e8097efa20c748eccfeb3c5f30e":[6,0,0,0,1,5,2],
+"namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19a02922bd807343bfddac92841edf920da":[6,0,0,0,1,5,3],
+"namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19a2443c585425011b677ca6a7e316de8f5":[6,0,0,0,1,5,0],
+"namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19ac393ad534d24ee1e74ad0d4005b7a137":[6,0,0,0,1,5,4],
+"namespacelibcamera_1_1controls_1_1draft.html#a1b20de6837fe558585420060c1eb9c19ae77b64dc39a2dcf1cb33b6cdef1b1c59":[6,0,0,0,1,5,1],
+"namespacelibcamera_1_1controls_1_1draft.html#a2207806111da3a0adb610f78284443a5":[6,0,0,0,1,1],
+"namespacelibcamera_1_1controls_1_1draft.html#a2207806111da3a0adb610f78284443a5a33f46b7e50cfd4a3eb7f059861147502":[6,0,0,0,1,1,2],
+"namespacelibcamera_1_1controls_1_1draft.html#a2207806111da3a0adb610f78284443a5a392092348f70aa087670aef4481cc413":[6,0,0,0,1,1,1],
+"namespacelibcamera_1_1controls_1_1draft.html#a2207806111da3a0adb610f78284443a5a5fcb9524c2bfca06d67463f7cb1e7a4f":[6,0,0,0,1,1,0],
+"namespacelibcamera_1_1controls_1_1draft.html#a2207806111da3a0adb610f78284443a5ae2d41291358cea9fc25d6898ae759b41":[6,0,0,0,1,1,3],
 "namespacelibcamera_1_1controls_1_1draft.html#a234649f716de8bd83bc8df1c9a1e6517":[6,0,0,0,1,17],
 "namespacelibcamera_1_1controls_1_1draft.html#a2d5ec01e658a46c7e58a0b5f935fa4df":[6,0,0,0,1,10],
 "namespacelibcamera_1_1controls_1_1draft.html#a3aca0b908f66fc2b7cd4449dce29702a":[6,0,0,0,1,9],
@@ -118,18 +136,18 @@ var NAVTREEINDEX13 =
 "orientation_8h.html":[8,0,1,0,12],
 "orientation_8h_source.html":[8,0,1,0,12],
 "pages.html":[],
-"pipeline__handler_8h.html":[8,0,1,0,1,29],
-"pipeline__handler_8h.html#a8dae35473d8718ef287a93c2092c47bb":[8,0,1,0,1,29,3],
-"pipeline__handler_8h_source.html":[8,0,1,0,1,29],
+"pipeline__handler_8h.html":[8,0,1,0,1,30],
+"pipeline__handler_8h.html#a8dae35473d8718ef287a93c2092c47bb":[8,0,1,0,1,30,3],
+"pipeline__handler_8h_source.html":[8,0,1,0,1,30],
 "pixel__format_8h.html":[8,0,1,0,13],
 "pixel__format_8h_source.html":[8,0,1,0,13],
 "private_8h_source.html":[8,0,1,0,0,13],
-"process_8h.html":[8,0,1,0,1,30],
-"process_8h_source.html":[8,0,1,0,1,30],
+"process_8h.html":[8,0,1,0,1,31],
+"process_8h_source.html":[8,0,1,0,1,31],
 "property__ids_8h.html":[8,0,0,0,0,4],
 "property__ids_8h_source.html":[8,0,0,0,0,4],
-"pub__key_8h.html":[8,0,1,0,1,31],
-"pub__key_8h_source.html":[8,0,1,0,1,31],
+"pub__key_8h.html":[8,0,1,0,1,32],
+"pub__key_8h_source.html":[8,0,1,0,1,32],
 "pwl_8h.html":[8,0,2,0,1,15],
 "pwl_8h_source.html":[8,0,2,0,1,15],
 "request_8h.html":[8,0,1,0,14],
@@ -139,13 +157,13 @@ var NAVTREEINDEX13 =
 "shared__fd_8h.html":[8,0,1,0,0,15],
 "shared__fd_8h_source.html":[8,0,1,0,0,15],
 "shared__mem__object_8cpp.html":[8,0,2,1,2],
-"shared__mem__object_8h_source.html":[8,0,1,0,1,33],
+"shared__mem__object_8h_source.html":[8,0,1,0,1,34],
 "signal_8h.html":[8,0,1,0,0,16],
 "signal_8h_source.html":[8,0,1,0,0,16],
 "software__isp_8cpp.html":[8,0,2,1,0,2],
 "software__isp_8h_source.html":[8,0,1,0,1,1,1],
-"source__paths_8h.html":[8,0,1,0,1,34],
-"source__paths_8h_source.html":[8,0,1,0,1,34],
+"source__paths_8h.html":[8,0,1,0,1,35],
+"source__paths_8h_source.html":[8,0,1,0,1,35],
 "stream_8h.html":[8,0,1,0,15],
 "stream_8h_source.html":[8,0,1,0,15],
 "structlibcamera_1_1CameraSensorProperties.html":[6,0,0,14],
@@ -231,23 +249,5 @@ var NAVTREEINDEX13 =
 "structlibcamera_1_1FrameMetadata_1_1Plane.html":[6,0,0,46,0],
 "structlibcamera_1_1FrameMetadata_1_1Plane.html":[7,0,0,45,0],
 "structlibcamera_1_1FrameMetadata_1_1Plane.html#a4537c0ebf8254ab70a4f410ca75e401b":[6,0,0,46,0,0],
-"structlibcamera_1_1FrameMetadata_1_1Plane.html#a4537c0ebf8254ab70a4f410ca75e401b":[7,0,0,45,0,0],
-"structlibcamera_1_1IPABuffer.html":[6,0,0,51],
-"structlibcamera_1_1IPABuffer.html":[7,0,0,50],
-"structlibcamera_1_1IPABuffer.html#a256847bdaa0df391855638eef7b027b5":[6,0,0,51,1],
-"structlibcamera_1_1IPABuffer.html#a256847bdaa0df391855638eef7b027b5":[7,0,0,50,1],
-"structlibcamera_1_1IPABuffer.html#a95ec7586dc1c7060228423f182329ca6":[6,0,0,51,0],
-"structlibcamera_1_1IPABuffer.html#a95ec7586dc1c7060228423f182329ca6":[7,0,0,50,0],
-"structlibcamera_1_1IPACameraSensorInfo.html":[6,0,0,52],
-"structlibcamera_1_1IPACameraSensorInfo.html":[7,0,0,51],
-"structlibcamera_1_1IPACameraSensorInfo.html#a011900b9facd39607ad8d2e73cf2ec41":[6,0,0,52,10],
-"structlibcamera_1_1IPACameraSensorInfo.html#a011900b9facd39607ad8d2e73cf2ec41":[7,0,0,51,10],
-"structlibcamera_1_1IPACameraSensorInfo.html#a19967b85dd282779a331c126460d2ce8":[6,0,0,52,7],
-"structlibcamera_1_1IPACameraSensorInfo.html#a19967b85dd282779a331c126460d2ce8":[7,0,0,51,7],
-"structlibcamera_1_1IPACameraSensorInfo.html#a76f7926bb79f7f80781f67367ec4d13d":[6,0,0,52,3],
-"structlibcamera_1_1IPACameraSensorInfo.html#a76f7926bb79f7f80781f67367ec4d13d":[7,0,0,51,3],
-"structlibcamera_1_1IPACameraSensorInfo.html#a9bac676fe3ea200b18d42a3561c8a851":[6,0,0,52,8],
-"structlibcamera_1_1IPACameraSensorInfo.html#a9bac676fe3ea200b18d42a3561c8a851":[7,0,0,51,8],
-"structlibcamera_1_1IPACameraSensorInfo.html#aade1f3bd6e1d04666746d157382d6a23":[6,0,0,52,2],
-"structlibcamera_1_1IPACameraSensorInfo.html#aade1f3bd6e1d04666746d157382d6a23":[7,0,0,51,2]
+"structlibcamera_1_1FrameMetadata_1_1Plane.html#a4537c0ebf8254ab70a4f410ca75e401b":[7,0,0,45,0,0]
 };
