@@ -1,5 +1,15 @@
 var NAVTREEINDEX3 =
 {
+"classlibcamera_1_1DeviceEnumerator.html#a3c539b6b75170fcf224ed5574c971842":[7,0,0,32,4],
+"classlibcamera_1_1DeviceEnumerator.html#a961a9182c004939d55f1227b7c1d05c3":[6,0,0,33,6],
+"classlibcamera_1_1DeviceEnumerator.html#a961a9182c004939d55f1227b7c1d05c3":[7,0,0,32,6],
+"classlibcamera_1_1DeviceEnumerator.html#ac18ba2dec80bb01666bc635f4556e2c3":[6,0,0,33,1],
+"classlibcamera_1_1DeviceEnumerator.html#ac18ba2dec80bb01666bc635f4556e2c3":[7,0,0,32,1],
+"classlibcamera_1_1DeviceMatch.html":[6,0,0,34],
+"classlibcamera_1_1DeviceMatch.html":[7,0,0,33],
+"classlibcamera_1_1DeviceMatch.html#a118bb7d1b27680fe22b4b339ae8c5207":[6,0,0,34,0],
+"classlibcamera_1_1DeviceMatch.html#a118bb7d1b27680fe22b4b339ae8c5207":[7,0,0,33,0],
+"classlibcamera_1_1DeviceMatch.html#acf0e970d41842da73e1ee25bfb24de3a":[6,0,0,34,1],
 "classlibcamera_1_1DeviceMatch.html#acf0e970d41842da73e1ee25bfb24de3a":[7,0,0,33,1],
 "classlibcamera_1_1DeviceMatch.html#ae9923a86604c13eb08c0273b95d0a923":[6,0,0,34,2],
 "classlibcamera_1_1DeviceMatch.html#ae9923a86604c13eb08c0273b95d0a923":[7,0,0,33,2],
@@ -35,8 +45,12 @@ var NAVTREEINDEX3 =
 "classlibcamera_1_1DmaSyncer.html#a044f26d4cf31fa3942e70b3016c6a5a9a70a2a84088d405a2e3f1e3accaa16723":[7,0,0,35,0,2],
 "classlibcamera_1_1DmaSyncer.html#a044f26d4cf31fa3942e70b3016c6a5a9a7a1a5f3e79fdc91edf2f5ead9d66abb4":[6,0,0,36,0,0],
 "classlibcamera_1_1DmaSyncer.html#a044f26d4cf31fa3942e70b3016c6a5a9a7a1a5f3e79fdc91edf2f5ead9d66abb4":[7,0,0,35,0,0],
+"classlibcamera_1_1DmaSyncer.html#a80d45f7341ff92f776046d829db654a8":[6,0,0,36,2],
+"classlibcamera_1_1DmaSyncer.html#a80d45f7341ff92f776046d829db654a8":[7,0,0,35,2],
 "classlibcamera_1_1DmaSyncer.html#aadceed1b14a60264cd24751db2562717":[6,0,0,36,1],
 "classlibcamera_1_1DmaSyncer.html#aadceed1b14a60264cd24751db2562717":[7,0,0,35,1],
+"classlibcamera_1_1DmaSyncer.html#ae9f7fdfab90b99bd42fa224ce7e021b2":[6,0,0,36,3],
+"classlibcamera_1_1DmaSyncer.html#ae9f7fdfab90b99bd42fa224ce7e021b2":[7,0,0,35,3],
 "classlibcamera_1_1EventDispatcher.html":[6,0,0,37],
 "classlibcamera_1_1EventDispatcher.html":[7,0,0,36],
 "classlibcamera_1_1EventDispatcher.html#a05dcf97c0bfd594b722b2deb628e4cc2":[6,0,0,37,1],
@@ -235,19 +249,5 @@ var NAVTREEINDEX3 =
 "classlibcamera_1_1FrameBuffer.html#af5b65931df6a8354f8bb2d932e0b1d72":[7,0,0,43,3],
 "classlibcamera_1_1FrameBuffer.html#af6a635f124b735fc5fd7b3b145d970da":[6,0,0,44,4],
 "classlibcamera_1_1FrameBuffer.html#af6a635f124b735fc5fd7b3b145d970da":[7,0,0,43,4],
-"classlibcamera_1_1FrameBufferAllocator.html":[6,0,0,45],
-"classlibcamera_1_1FrameBufferAllocator.html":[7,0,0,44],
-"classlibcamera_1_1FrameBufferAllocator.html#a184749ea64aeba195bd7c8a880311cd4":[6,0,0,45,4],
-"classlibcamera_1_1FrameBufferAllocator.html#a184749ea64aeba195bd7c8a880311cd4":[7,0,0,44,4],
-"classlibcamera_1_1FrameBufferAllocator.html#a1d115534f49614e3466f5e86fbc43f2a":[6,0,0,45,1],
-"classlibcamera_1_1FrameBufferAllocator.html#a1d115534f49614e3466f5e86fbc43f2a":[7,0,0,44,1],
-"classlibcamera_1_1FrameBufferAllocator.html#a7e35d2d59174137dfd3395b1e802a148":[6,0,0,45,2],
-"classlibcamera_1_1FrameBufferAllocator.html#a7e35d2d59174137dfd3395b1e802a148":[7,0,0,44,2],
-"classlibcamera_1_1FrameBufferAllocator.html#a8207ce42ed29ebae26378357c2054ee7":[6,0,0,45,3],
-"classlibcamera_1_1FrameBufferAllocator.html#a8207ce42ed29ebae26378357c2054ee7":[7,0,0,44,3],
-"classlibcamera_1_1FrameBufferAllocator.html#ab66590d49bdb5dba848a74604f0b2597":[6,0,0,45,0],
-"classlibcamera_1_1FrameBufferAllocator.html#ab66590d49bdb5dba848a74604f0b2597":[7,0,0,44,0],
-"classlibcamera_1_1FrameBuffer_1_1Private.html":[6,0,0,44,1],
-"classlibcamera_1_1FrameBuffer_1_1Private.html":[7,0,0,43,1],
-"classlibcamera_1_1FrameBuffer_1_1Private.html#a30efe76aa77087961accb7d050c898ba":[6,0,0,44,1,1]
+"classlibcamera_1_1FrameBufferAllocator.html":[6,0,0,45]
 };
