@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['b_0',['b',['../classlibcamera_1_1ipa_1_1Vector.html#a9a3b7ce15bc5bee09e82e03f482fb578',1,'libcamera::ipa::Vector::b() const'],['../classlibcamera_1_1ipa_1_1Vector.html#a1674fae77c1fd131d24f2a2c49a82a11',1,'libcamera::ipa::Vector::b()']]],
+  ['b_0',['b',['../structlibcamera_1_1DebayerParams_1_1CcmColumn.html#a0bf5cd03cd38b5b8a21edc450e3ab2ce',1,'libcamera::DebayerParams::CcmColumn::b'],['../classlibcamera_1_1Vector.html#a0f5cdc92b62075308772ba61b4a3fbcf',1,'libcamera::Vector::b() const'],['../classlibcamera_1_1Vector.html#a29055157486dce081d2be29ff7308dd0',1,'libcamera::Vector::b()']]],
   ['backtrace_1',['Backtrace',['../classlibcamera_1_1Backtrace.html',1,'libcamera::Backtrace'],['../classlibcamera_1_1Backtrace.html#a330b7c9133d7c7c8e4a03e6f9d668caf',1,'libcamera::Backtrace::Backtrace()']]],
   ['backtrace_2',['backtrace',['../classlibcamera_1_1Logger.html#adb8344666236c0db52a5de8dfdaf69bd',1,'libcamera::Logger']]],
   ['backtrace_2eh_3',['backtrace.h',['../backtrace_8h.html',1,'']]],
@@ -26,25 +26,26 @@ var searchData=
   ['blacklevel_5f_23',['blackLevel_',['../classlibcamera_1_1ipa_1_1CameraSensorHelper.html#a6bbe77cc220f5b4d8488d5f6b306c0d9',1,'libcamera::ipa::CameraSensorHelper']]],
   ['blacklevelcorrection_24',['BlackLevelCorrection',['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1BlackLevelCorrection.html',1,'libcamera::ipa::ipu3::algorithms']]],
   ['blc_2eh_25',['blc.h',['../blc_8h.html',1,'']]],
-  ['blue_26',['blue',['../structlibcamera_1_1DebayerParams.html#ab4cb88f5e7ce789a1ad85a824ce71905',1,'libcamera::DebayerParams::blue'],['../structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html#ab1e6f5cca85d97dee2be4a951128f4ef',1,'libcamera::ipa::ipu3::algorithms::Accumulator::blue'],['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a1714e69dac816940e1ae455dbfbd6ab0',1,'libcamera::ipa::ipu3::IPAActiveState::blue']]],
-  ['bound_27',['Bound',['../structlibcamera_1_1ipa_1_1AgcMeanLuminance_1_1AgcConstraint.html#a784f23cb354934b0615e2dbc75578759',1,'libcamera::ipa::AgcMeanLuminance::AgcConstraint']]],
-  ['bound_28',['bound',['../structlibcamera_1_1ipa_1_1AgcMeanLuminance_1_1AgcConstraint.html#a9252318f96245592222f68eb3ce0238a',1,'libcamera::ipa::AgcMeanLuminance::AgcConstraint']]],
-  ['bound_5fmethod_2eh_29',['bound_method.h',['../bound__method_8h.html',1,'']]],
-  ['boundedto_30',['boundedTo',['../classlibcamera_1_1Size.html#adf1ad11e34e8d3d64577c6c8b2d6932b',1,'libcamera::Size::boundedTo()'],['../classlibcamera_1_1Rectangle.html#af6ab6db441d6ebb0c3032c0b26df243e',1,'libcamera::Rectangle::boundedTo()']]],
-  ['boundedtoaspectratio_31',['boundedToAspectRatio',['../classlibcamera_1_1Size.html#ab44f288148efb162ba9d2d54cf844242',1,'libcamera::Size']]],
-  ['boundto_32',['boundTo',['../classlibcamera_1_1Size.html#a29b267bc4fdc51c9b50a5cc7b98ae4ba',1,'libcamera::Size']]],
-  ['bpl_33',['bpl',['../structlibcamera_1_1V4L2DeviceFormat_1_1Plane.html#a8e993f521224c108e3b4225d4d50fe4e',1,'libcamera::V4L2DeviceFormat::Plane']]],
-  ['brightness_34',['Brightness',['../namespacelibcamera_1_1controls.html#ab2c40c5fe0916c0c1734fbb5b8e4faf2',1,'libcamera::controls']]],
-  ['buffercompleted_35',['bufferCompleted',['../classlibcamera_1_1Camera.html#a5fe034be26009e8173b683db8e8fb80a',1,'libcamera::Camera']]],
-  ['buffercount_36',['bufferCount',['../structlibcamera_1_1StreamConfiguration.html#a52204a14781dd3687657b790ba894e0a',1,'libcamera::StreamConfiguration']]],
-  ['buffermap_37',['BufferMap',['../classlibcamera_1_1Request.html#a6ef726ce36fbc51d3ebd6e1d2366cd87',1,'libcamera::Request']]],
-  ['bufferready_38',['bufferReady',['../classlibcamera_1_1V4L2VideoDevice.html#a549153ee5ea43d387aa4fa596f37b66e',1,'libcamera::V4L2VideoDevice']]],
-  ['buffers_39',['buffers',['../classlibcamera_1_1FrameBufferAllocator.html#a8207ce42ed29ebae26378357c2054ee7',1,'libcamera::FrameBufferAllocator::buffers()'],['../classlibcamera_1_1Request.html#a24c7da0445dbb2bf61956a264e4c983e',1,'libcamera::Request::buffers()']]],
-  ['bus_5finfo_40',['bus_info',['../structlibcamera_1_1V4L2Capability.html#a247346aef2cfc6df6c33750264798d05',1,'libcamera::V4L2Capability']]],
-  ['busname_41',['busName',['../classlibcamera_1_1V4L2VideoDevice.html#a566391f6709ea9a07c3ce35199fcf5da',1,'libcamera::V4L2VideoDevice']]],
-  ['busy_42',['busy',['../classlibcamera_1_1MediaDevice.html#a3f58c03f422e84824a9e2e35afcaa2bb',1,'libcamera::MediaDevice']]],
-  ['byte_5fstream_5fbuffer_2eh_43',['byte_stream_buffer.h',['../byte__stream__buffer_8h.html',1,'']]],
-  ['bytespergroup_44',['bytesPerGroup',['../structlibcamera_1_1PixelFormatInfo_1_1Plane.html#adceda8c9551a6d7475a0f1d31be97869',1,'libcamera::PixelFormatInfo::Plane']]],
-  ['bytestreambuffer_45',['ByteStreamBuffer',['../classlibcamera_1_1ByteStreamBuffer.html',1,'libcamera::ByteStreamBuffer'],['../classlibcamera_1_1ByteStreamBuffer.html#aab08c12dd64a532b30e6606688a96d70',1,'libcamera::ByteStreamBuffer::ByteStreamBuffer(const uint8_t *base, size_t size)'],['../classlibcamera_1_1ByteStreamBuffer.html#abfa1e97f387a892b20ab201b74fe82c0',1,'libcamera::ByteStreamBuffer::ByteStreamBuffer(uint8_t *base, size_t size)'],['../classlibcamera_1_1ByteStreamBuffer.html#a15b0355a9b76b2cc9641ca228839000c',1,'libcamera::ByteStreamBuffer::ByteStreamBuffer(ByteStreamBuffer &amp;&amp;other)']]],
-  ['bytesused_46',['bytesused',['../structlibcamera_1_1FrameMetadata_1_1Plane.html#a4537c0ebf8254ab70a4f410ca75e401b',1,'libcamera::FrameMetadata::Plane']]]
+  ['blue_26',['blue',['../structlibcamera_1_1DebayerParams.html#a0111b2ccaa61e1f5e19095a752a8a5c0',1,'libcamera::DebayerParams::blue'],['../structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html#ab1e6f5cca85d97dee2be4a951128f4ef',1,'libcamera::ipa::ipu3::algorithms::Accumulator::blue'],['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a1714e69dac816940e1ae455dbfbd6ab0',1,'libcamera::ipa::ipu3::IPAActiveState::blue']]],
+  ['blueccm_27',['blueCcm',['../structlibcamera_1_1DebayerParams.html#a7067e64c2b77c1eff1854cf28d4009d2',1,'libcamera::DebayerParams']]],
+  ['bound_28',['Bound',['../structlibcamera_1_1ipa_1_1AgcMeanLuminance_1_1AgcConstraint.html#a784f23cb354934b0615e2dbc75578759',1,'libcamera::ipa::AgcMeanLuminance::AgcConstraint']]],
+  ['bound_29',['bound',['../structlibcamera_1_1ipa_1_1AgcMeanLuminance_1_1AgcConstraint.html#a9252318f96245592222f68eb3ce0238a',1,'libcamera::ipa::AgcMeanLuminance::AgcConstraint']]],
+  ['bound_5fmethod_2eh_30',['bound_method.h',['../bound__method_8h.html',1,'']]],
+  ['boundedto_31',['boundedTo',['../classlibcamera_1_1Size.html#a2094d73784a8aece896c364cc2bda5ca',1,'libcamera::Size::boundedTo()'],['../classlibcamera_1_1Rectangle.html#af6ab6db441d6ebb0c3032c0b26df243e',1,'libcamera::Rectangle::boundedTo()']]],
+  ['boundedtoaspectratio_32',['boundedToAspectRatio',['../classlibcamera_1_1Size.html#ab44f288148efb162ba9d2d54cf844242',1,'libcamera::Size']]],
+  ['boundto_33',['boundTo',['../classlibcamera_1_1Size.html#a29b267bc4fdc51c9b50a5cc7b98ae4ba',1,'libcamera::Size']]],
+  ['bpl_34',['bpl',['../structlibcamera_1_1V4L2DeviceFormat_1_1Plane.html#a8e993f521224c108e3b4225d4d50fe4e',1,'libcamera::V4L2DeviceFormat::Plane']]],
+  ['brightness_35',['Brightness',['../namespacelibcamera_1_1controls.html#ab2c40c5fe0916c0c1734fbb5b8e4faf2',1,'libcamera::controls']]],
+  ['buffercompleted_36',['bufferCompleted',['../classlibcamera_1_1Camera.html#a5fe034be26009e8173b683db8e8fb80a',1,'libcamera::Camera']]],
+  ['buffercount_37',['bufferCount',['../structlibcamera_1_1StreamConfiguration.html#a52204a14781dd3687657b790ba894e0a',1,'libcamera::StreamConfiguration']]],
+  ['buffermap_38',['BufferMap',['../classlibcamera_1_1Request.html#a6ef726ce36fbc51d3ebd6e1d2366cd87',1,'libcamera::Request']]],
+  ['bufferready_39',['bufferReady',['../classlibcamera_1_1V4L2VideoDevice.html#a549153ee5ea43d387aa4fa596f37b66e',1,'libcamera::V4L2VideoDevice']]],
+  ['buffers_40',['buffers',['../classlibcamera_1_1FrameBufferAllocator.html#a8207ce42ed29ebae26378357c2054ee7',1,'libcamera::FrameBufferAllocator::buffers()'],['../classlibcamera_1_1Request.html#a24c7da0445dbb2bf61956a264e4c983e',1,'libcamera::Request::buffers()']]],
+  ['bus_5finfo_41',['bus_info',['../structlibcamera_1_1V4L2Capability.html#a247346aef2cfc6df6c33750264798d05',1,'libcamera::V4L2Capability']]],
+  ['busname_42',['busName',['../classlibcamera_1_1V4L2VideoDevice.html#a566391f6709ea9a07c3ce35199fcf5da',1,'libcamera::V4L2VideoDevice']]],
+  ['busy_43',['busy',['../classlibcamera_1_1MediaDevice.html#a3f58c03f422e84824a9e2e35afcaa2bb',1,'libcamera::MediaDevice']]],
+  ['byte_5fstream_5fbuffer_2eh_44',['byte_stream_buffer.h',['../byte__stream__buffer_8h.html',1,'']]],
+  ['bytespergroup_45',['bytesPerGroup',['../structlibcamera_1_1PixelFormatInfo_1_1Plane.html#adceda8c9551a6d7475a0f1d31be97869',1,'libcamera::PixelFormatInfo::Plane']]],
+  ['bytestreambuffer_46',['ByteStreamBuffer',['../classlibcamera_1_1ByteStreamBuffer.html',1,'libcamera::ByteStreamBuffer'],['../classlibcamera_1_1ByteStreamBuffer.html#aab08c12dd64a532b30e6606688a96d70',1,'libcamera::ByteStreamBuffer::ByteStreamBuffer(const uint8_t *base, size_t size)'],['../classlibcamera_1_1ByteStreamBuffer.html#abfa1e97f387a892b20ab201b74fe82c0',1,'libcamera::ByteStreamBuffer::ByteStreamBuffer(uint8_t *base, size_t size)'],['../classlibcamera_1_1ByteStreamBuffer.html#a15b0355a9b76b2cc9641ca228839000c',1,'libcamera::ByteStreamBuffer::ByteStreamBuffer(ByteStreamBuffer &amp;&amp;other)']]],
+  ['bytesused_47',['bytesused',['../structlibcamera_1_1FrameMetadata_1_1Plane.html#a4537c0ebf8254ab70a4f410ca75e401b',1,'libcamera::FrameMetadata::Plane']]]
 ];
